# Pioneers in the information age!
### 信息时代弄潮儿! 技术奇客的工具箱
-- by [ITGeeker.net](https://www.itgeeker.net)

###########################################################################
#    Copyright 2026 奇客罗方智能科技 https://www.geekercloud.com
#    ITGeeker.net <alanljj@gmail.com>
###########################################################################

## Update log:

2025-11-06 v0.2.7
1. Add import excel head name list.

2025-11-06 v0.2.6
1. Add Chinese ID check function, fixed former bug.
2. Add convert number to Chinese RMB.